@@ -1,10 +1,10 @@
-/*	$Id: gshhs.h,v 1.16 2007/08/28 18:40:26 guru Exp $
+/*	$Id: gshhs.h,v 1.18 2008/05/02 00:44:42 guru Exp $
  *
  * Include file defining structures used in gshhs.c
  *
  * Paul Wessel, SOEST
  *
- *	Copyright (c) 1996-2007 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1996-2008 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -37,6 +37,10 @@
 #include <stdlib.h>
 #include <math.h>
 
+#ifdef WIN32
+#pragma warning( disable : 4996 )
+#endif
+
 #ifndef M_PI
 #define M_PI          3.14159265358979323846
 #endif
